pub struct ScoreStandardized(/* private fields */);Expand description
This struct represents a “standardized” score (read below).
Engines (should) return a Score dependent on whose turn it is to move.
ScoreStandardized is a score independent of whose turn it is to move.
So, x means that white has an advantage of x, -x means that black has an advantage of x.
Get this by calling Score::standardized.
Note that you need to specify whose turn it is to move.
⚠️ While the UCI protocol does say engines should score from their point of view, you should verify this is the case with the engine you’re using.
Implementations